@@ -30,6 +30,8 @@ from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
 from grafeas.grafeas_v1.services.grafeas import pagers
@@ -275,7 +277,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         request: Union[grafeas.GetOccurrenceRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> grafeas.Occurrence:
@@ -346,7 +348,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         *,
         parent: str = None,
         filter: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListOccurrencesPager:
@@ -431,7 +433,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         request: Union[grafeas.DeleteOccurrenceRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -497,7 +499,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         *,
         parent: str = None,
         occurrence: grafeas.Occurrence = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> grafeas.Occurrence:
@@ -576,7 +578,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         *,
         parent: str = None,
         occurrences: Sequence[grafeas.Occurrence] = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> grafeas.BatchCreateOccurrencesResponse:
@@ -659,7 +661,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         name: str = None,
         occurrence: grafeas.Occurrence = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> grafeas.Occurrence:
@@ -743,7 +745,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         request: Union[grafeas.GetOccurrenceNoteRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> grafeas.Note:
@@ -816,7 +818,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         request: Union[grafeas.GetNoteRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> grafeas.Note:
@@ -887,7 +889,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         *,
         parent: str = None,
         filter: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListNotesPager:
@@ -972,7 +974,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         request: Union[grafeas.DeleteNoteRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -1037,7 +1039,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         parent: str = None,
         note_id: str = None,
         note: grafeas.Note = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> grafeas.Note:
@@ -1123,7 +1125,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         *,
         parent: str = None,
         notes: Sequence[grafeas.BatchCreateNotesRequest.NotesEntry] = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> grafeas.BatchCreateNotesResponse:
@@ -1203,7 +1205,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         name: str = None,
         note: grafeas.Note = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> grafeas.Note:
@@ -1288,7 +1290,7 @@ class GrafeasClient(metaclass=GrafeasClientMeta):
         *,
         name: str = None,
         filter: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListNoteOccurrencesPager:
